@@ -1,5 +1,5 @@
 # Application Name: NoobNote
-# Version: v.0.1
+# Version: v.1.1 Developer
 # Author: NoobScience
 # Author Website: https://newtoallofthis123.github.io/About
 # Application Docs and Trobule Shooting Website: https://newtoallofthis123.github.io/NoobNote
@@ -16,16 +16,27 @@ from tkinter.messagebox import askquestion
 from tkinter.messagebox import showerror
 from tkinter.messagebox import askokcancel
 import webbrowser
-from pathlib import Path
+# import configparser
 try:
     import os, sys
+    import pkg_resources
+    import subprocess
     import win32print
     import win32api
+    # from pathlib import Path
 except:
     pass
 
+# required = {'pyqrcode' ,  'rich'}
+# installed = {pkg.key for pkg in pkg_resources.working_set}
+# missing = required - installed
+# if missing:
+#     python = sys.executable
+#     subprocess.check_call([python, '-m', 'pip', 'install', *missing], stdout=subprocess.DEVNULL)
+# else:
+#     pass
+# change_dir_to = os.chdir(Path.home())
 def main():
-    change_dir = Path.home()
     gui = Tk()
     gui.title("NoobNote")
     try:
@@ -43,6 +54,26 @@ def main():
     global selectedText
     selectedText = False
 
+    global wrapVar
+    wrapVar = False
+
+    global fontvar
+    global sizevar
+    # config = configparser.ConfigParser()        
+    # config.read("setting.ini")
+    # Font = 'config['Font']'
+    # Colors = config['Colors']
+    # Profile = config['Profile']
+    fontvar = 'Cascadia Code'
+    sizevar = 14
+    bgvar = "white"
+    fgvar = "black"
+    selectbgvar = "#F9C500"
+    selectfgvar = "black"
+    # authorvar = Profile["authorvar"]
+    # projectnamevar = Profile["projectnamevar"]
+    # linkvar = Profile["linkvar"]
+
     def newFile(e):
         text.delete("1.0", END)
         gui.title('New File - NoobNote')
@@ -53,7 +84,7 @@ def main():
             text.delete("1.0", END)
             #gui.title('New File - NoobScience')
             #status_bar.config(text="N    ")
-            file = filedialog.askopenfilename(initialdir=change_dir, title="Choose A File", filetypes=(("Text Files", "*.txt"), ("Python Files", "*.py"),  ("All Files", "*.*")))
+            file = filedialog.askopenfilename(initialdir="C:/", title="Choose A File", filetypes=(("All Files", "*.*"),("Text Files", "*.txt"), ("Python Files", "*.py"), ("Config Files", "*.ini") ,("Ruby Files", "*.rb"), ("HTML Files", "*.html"), ("JSON Files", "*.json"), ("Javascript Files", "*.js"), ("CSS Files", "*.css"), ("Shell Files", "*.sh"), ("Batch Files", "*.bat")))
             if file:
                 global openFilename
                 openFilename = file
@@ -73,7 +104,7 @@ def main():
 
     def saveAs(e):
         try:
-            file = filedialog.asksaveasfilename(defaultextension=".*", initialdir=change_dir, title="Save file as", filetypes=(("Text Files", "*.txt"), ("Python Files", "*.py"),  ("All Files", "*.*")))
+            file = filedialog.asksaveasfilename(defaultextension=".*", initialdir="C:/", title="Save file as", filetypes=(("All Files", "*.*"),("Text Files", "*.txt"), ("Python Files", "*.py"), ("Config Files", "*.ini") ,("Ruby Files", "*.rb"), ("HTML Files", "*.html"), ("JSON Files", "*.json"), ("Javascript Files", "*.js"), ("CSS Files", "*.css"), ("Shell Files", "*.sh"), ("Batch Files", "*.bat")))
             if file:
                 name = file
                 status_bar.config(text=f'{name}  opened')
@@ -100,6 +131,10 @@ def main():
         except:
             showerror("Not Saved", "No file saved")
 
+    def save_exit(e):
+        saveFile(False)
+        gui.quit()
+
     def cutText(e):
         global selectedText
         if e:
@@ -228,12 +263,12 @@ def main():
         #colorChoice = colorchooser.askcolor()[1]
         status_bar.config(text=f'Theme set to : light', bg="white", fg="black")
         gui.config(bg="white")
-        text.config(fg = "black",bg="white", selectbackground="#0618FF", selectforeground="white")
+        text.config(fg = "black",bg="white", selectbackground=selectbgvar, selectforeground=selectfgvar)
         
     def darkTheme(e):
         status_bar.config(text=f'Theme set to : dark', bg="white", fg="black")
         gui.config(bg="black")
-        text.config(fg="white",bg="black", selectbackground="yellow", selectforeground="black")
+        text.config(fg="white",bg="black", selectbackground="yellow", selectforeground="black", insertbackground="white")
     
     def relaxTheme(e):
         status_bar.config(text=f'Theme set to : relax', bg="#F2DD2D", fg="black")
@@ -241,6 +276,7 @@ def main():
         text.config(fg="black",bg="#F2DD2D", selectbackground="#FA9133", selectforeground="black")
         
     def timeDate(e):
+        global timeAnddate
         from datetime import datetime
         from datetime import date
         current_t = datetime.now()
@@ -255,7 +291,17 @@ def main():
 
     def clearAll(e):
         text.delete(1.0, END)
-        status_bar.config(text='All Text Delted')
+        status_bar.config(text='All Text Deleted')
+
+    def del_text(e):
+        try:
+            text.delete(SEL_FIRST, SEL_LAST)
+            status_bar.config(text='Selected Text Deleted')
+        except:
+            showerror("Error", "No Text Selected to Search")
+
+    def right_click_menu(e):
+        rightClickmenu.tk_popup(e.x_root, e.y_root)
         
     def openNoobweb():
         webbrowser.open("https://newtoallofthis123.github.io/About")
@@ -278,6 +324,25 @@ def main():
             import NoobNote
         else:
             pass
+    
+    def timedate():
+        global timeAnddate
+        from datetime import datetime
+        from datetime import date
+        current_t = datetime.now()
+        current_date = str(date.today())
+        current_t_f = current_t.strftime("%H:%M:%S") 
+        timeAnddate = (f'{current_t_f} {current_date}')
+        return timeAnddate
+    
+    # def writer_profile():
+    #     global timeAnddate
+    #     author = authorvar
+    #     project = projectnamevar
+    #     link = linkvar
+    #     time = timedate()
+    #     x = f'Author : {author}\nProject Name : {project}\nLink : {link}\nTime : {time}\n'
+    #     text.insert(END, x)
 
     def printFile(e):
         try:
@@ -300,6 +365,50 @@ def main():
 
     def quit1(e):
         gui.quit()
+
+    def settings(e):
+        try:
+            #text.delete(1.0, END)
+            #doc = open("setting.ini")
+            #gui.title("NoobNote Settings")
+            #docContent = doc.read()
+            #text.insert(END, docContent)
+            os.system("setting.ini")
+            gui.quit()
+            main()
+        except:
+            showerror("Settings", "setting.ini not Found")
+
+    def fontSettings(e):
+        text.config(font=(e, sizevar))
+
+    def zoomIn(e):
+        global sizevar
+        sizevar = int(sizevar) + 1
+        text.config(font=(fontvar, sizevar))
+
+    def zoomOut(e):
+        global sizevar
+        sizevar = int(sizevar) - 1
+        text.config(font=(fontvar, sizevar))
+
+    def sizeSettings(e):
+        text.config(font=e)
+
+    def word_wrap(e):
+        global wrapVar
+        if wrapVar:
+            text.config(wrap=WORD)
+            wrapVar = False
+        else:
+            wrapVar = True
+            text.config(wrap="none")
+
+    def insert_img():
+        img = filedialog.askopenfilename(initialdir='I:\github', title="Choose A File", filetypes=(("Image Files", "*.png"),))
+        image = PhotoImage(file=img)
+        insert_pos = text.index(INSERT)
+        text.image_create(insert_pos, image=image)
     
     def qr(e):
         try:
@@ -416,10 +525,7 @@ def main():
             def doc(e):
                 docs = Tk()
                 docs.title("Leaf Qr-Code Generator Docs")
-                try:
-                    docs.iconbitmap('icon.ico')
-                except:
-                    pass
+                docs.iconbitmap('icon.ico')
                 readme = 'readme.txt'
                 file = open(readme, 'r')
                 content = file.read()
@@ -438,10 +544,7 @@ def main():
             qrCode.geometry('500x500')
             qrCode.title("Leaf Qr-Code Generator")
             qrCode.configure(bg="black")
-            try:
-                qrCode.iconbitmap('icon.ico')
-            except:
-                pass
+            qrCode.iconbitmap('icon.ico')
 
             title = Label(qrCode, text="Leaf QrCode Generator", fg="#3FFFAB", bg="black", borderwidth=0, font=("Cascadia", 24))
             title.pack(padx=10, pady=10, ipady=6)
@@ -529,6 +632,82 @@ def main():
         _year = int(date_now.year)
         cal = calendar.calendar(_year)
         text.insert(END, cal)
+
+    def show_year_calendar():
+        from datetime import datetime
+        from datetime import date
+        import time
+        import calendar
+        year_cal = Tk()
+        year_cal.resizable(False, False)
+        year_cal.config(bg="black")
+        year_cal.iconbitmap('icon.ico')
+        date_now = date.today()
+        _month = int(date_now.month)
+        _year = int(date_now.year)
+        year_cal.title("Month Calendar for: " + str(_year))
+        cal = calendar.calendar(_year)
+        label = Label(year_cal, text=cal, fg="white", bg="black", font=("Cascadia Code", 12))
+        label.pack()
+
+    def show_month_calendar():
+        from datetime import datetime
+        from datetime import date
+        import time
+        import calendar    
+        month_cal = Tk()
+        month_cal.resizable(False, False)
+        month_cal.config(bg="black")
+        month_cal.iconbitmap('icon.ico')
+        date_now = date.today()
+        _month = int(date_now.month)
+        _year = int(date_now.year)
+        month_cal.title("Year Calendar for: " + str(_month) + "  " + str(_year))
+        cal = calendar.month(_year, _month)
+        label = Label(month_cal, text=cal, fg="white", bg="black", font=("Cascadia Code", 18))
+        label.pack()
+
+    def run(e):
+        if openFilename.endswith(".py"):
+            try:
+                os.system("C:/Users/User/AppData/Local/Programs/Python/Python39/python.exe " + openFilename)
+            except:
+                showerror("Python Not Found", "Python is not found in your path. Add it or try reinstalling or installing python")
+        if openFilename.endswith(".html"):
+            try:
+                folder = filedialog.askdirectory(initialdir='I:\github', title="Choose A folder",)
+                os.system("cd..")
+                os.system("cd " + folder)
+                os.system("start https://localhost:8000")
+                os.system("python -m http.server")
+            except:
+                showerror("Something went wrong", "SomeThing went wrong. Try agian or report the issue at https://github.com/newtoallofthis123/NoobNote/issues")
+        if openFilename.endswith(".java"):
+            try:
+                os.system("java " + openFilename)
+            except:
+                showerror("Something went wrong", "Check your code and check if java is in your system path")
+        if openFilename.endswith(".rb"):
+            try:
+                os.system("ruby " + openFilename)
+            except:
+                showerror("Something went wrong", "Check your code and check if ruby is in your system path")
+        if openFilename.endswith(".bat"):
+            try:
+                os.system(openFilename)
+            except:
+                showerror("Something went wrong", "Check your code or are you sure you are running on windows?")
+        if openFilename.endswith(".sh"):
+            try:
+                os.system("cd resources")
+                os.system("bash " + openFilename)
+            except:
+                showerror("Something went wrong", "Check your code and check if bash is in your system path")
+        if openFilename.endswith(".js"):
+            try:
+                os.system("node " + openFilename)
+            except:
+                showerror("Something went wrong", "Check your code and check if node is in your system path")
     
     def clock(e):
         try:
@@ -536,10 +715,7 @@ def main():
             clock_widget = Tk()
             clock_widget.geometry("540x100")
             clock_widget.title("Clock Widget")
-            try:
-                clock_widget.iconbitmap("icon.ico")
-            except:
-                pass
+            clock_widget.iconbitmap("icon.ico")
             def clockconfig():
                 time_clock = strftime('%H:%M:%S %p')
                 clock_text.config(text = time_clock)
@@ -552,34 +728,52 @@ def main():
             print("ShadowGuy123")
                 
     def search_google():
-        content = text.selection_get()
-        url = 'https://www.google.com/search?hl=en&q=' + content
-        webbrowser.open(url)
+        try:
+            content = text.selection_get()
+            url = 'https://www.google.com/search?hl=en&q=' + content
+            webbrowser.open(url)
+        except:
+            showerror("Error", "No Text Selected to Search")
     
     def search_bing():
-        content = text.selection_get()
-        url = 'https://www.bing.com/search?q=' + content
-        webbrowser.open(url)
+        try:
+            content = text.selection_get()
+            url = 'https://www.bing.com/search?q=' + content
+            webbrowser.open(url)
+        except:
+            showerror("Error", "No Text Selected to Search")
         
     def search_yt():
-        content = text.selection_get()
-        url = 'https://www.youtube.com/results?search_query=' + content
-        webbrowser.open(url)
+        try:
+            content = text.selection_get()
+            url = 'https://www.youtube.com/results?search_query=' + content
+            webbrowser.open(url)
+        except:
+            showerror("Error", "No Text Selected to Search")
 
     def search_searx():
-        content = text.selection_get()
-        url = 'https://searx.info/search?q=' + content
-        webbrowser.open(url)
+        try:
+            content = text.selection_get()
+            url = 'https://searx.info/search?q=' + content
+            webbrowser.open(url)
+        except:
+            showerror("Error", "No Text Selected to Search")
     
     def search_github():
-        content = text.selection_get()
-        url = 'https://github.com/search?q=' + content
-        webbrowser.open(url)
+        try:
+            content = text.selection_get()
+            url = 'https://github.com/search?q=' + content
+            webbrowser.open(url)
+        except:
+            showerror("Error", "No Text Selected to Search")
     
     def search_vtip():
-        content = text.selection_get()
-        url = 'https://www.virustotal.com/gui/search/' + content
-        webbrowser.open(url)
+        try:
+            content = text.selection_get()
+            url = 'https://www.virustotal.com/gui/search/' + content
+            webbrowser.open(url)
+        except:
+            showerror("Error", "No Text Selected to Search")
         
     def encode_64():
         try:
@@ -627,6 +821,9 @@ def main():
         hash_hexa = hash_str.hexdigest()
         text.insert(END, hash_hexa)
 
+    toolbar = Frame(gui)
+    toolbar.pack()
+
     root = Frame(gui)
     root.pack()
 
@@ -640,7 +837,7 @@ def main():
     textWidth = gui.winfo_screenwidth()
     textHeight = int(gui.winfo_screenheight())
 
-    text = Text(root, width=textWidth, height=textHeight, font=("Cascadia", 16), selectbackground="#0618FF", selectforeground="white", undo=True, yscrollcommand=scroll_text.set, wrap="none", xscrollcommand=horizontal_scroll.set, fg="black", bg="white",)
+    text = Text(root, width=textWidth, height=textHeight, font=(fontvar, sizevar), selectbackground=selectbgvar, selectforeground=selectfgvar, undo=True, yscrollcommand=scroll_text.set, xscrollcommand=horizontal_scroll.set, fg=fgvar, bg=bgvar,)
     text.pack()
 
     menu = Menu(gui)
@@ -656,7 +853,8 @@ def main():
     fileMenu.add_separator()
     fileMenu.add_command(label="Print", command=lambda: printFile(False))
     fileMenu.add_separator()
-    fileMenu.add_command(label="Exit", command=lambda: quit1(False))
+    fileMenu.add_command(label="Save & Exit", command=lambda: save_exit(False))
+    fileMenu.add_command(label="Exit", command=gui.quit())
 
     editMenu = Menu(menu, tearoff=False)
     menu.add_cascade(label="Edit", menu=editMenu)
@@ -665,9 +863,12 @@ def main():
     editMenu.add_command(label="Paste", command=lambda: pasteText(False))
     editMenu.add_command(label="Select All", command=lambda: selectAll(False))
     editMenu.add_command(label="Clear All", command=lambda: clearAll(False))
+    editMenu.add_command(label="Delete Selected", command= lambda: del_text(False))
     editMenu.add_separator()
     editMenu.add_command(label="Undo", command=text.edit_undo)
     editMenu.add_command(label="Redo", command=text.edit_redo)
+    #editMenu.add_separator()
+    #editMenu.add_command(label="Add Image", command=insert_img)
 
     textFormatMenu = Menu(menu, tearoff=False)
     menu.add_cascade(label="Format", menu=textFormatMenu)
@@ -675,8 +876,26 @@ def main():
     textFormatMenu.add_command(label="Italic", command=lambda: italicText(False))
     textFormatMenu.add_command(label="Underline", command=lambda: underlineText(False))
     textFormatMenu.add_separator()
+    textFormatMenu.add_command(label="Zoom In", command= lambda: zoomIn(False))
+    textFormatMenu.add_command(label="Zoom Out", command= lambda: zoomOut(False))
+    textFormatMenu.add_separator()
     textFormatMenu.add_command(label="Encode in Base64", command=encode_64)
     textFormatMenu.add_command(label="Decode Base64 String", command=decode_64)
+    textFormatMenu.add_separator()
+    textFormatMenu.add_checkbutton(label="Word Wrap", command= lambda: word_wrap(False))
+
+    FontSettings = Menu(menu, tearoff=False)
+    menu.add_cascade(label="Font", menu=FontSettings)
+    FontSettings.add_command(label="Arial", command=lambda: fontSettings("Arial"))
+    FontSettings.add_command(label="Lucida Console", command=lambda: fontSettings("Lucida Console"))
+    FontSettings.add_command(label="Cascadia Code", command=lambda: fontSettings("Cascadia Code"))
+    FontSettings.add_command(label="Microsoft Sans Serif", command=lambda: fontSettings("Microsoft Sans Serif"))
+    FontSettings.add_command(label="Consolas", command=lambda: fontSettings("Consolas"))
+    FontSettings.add_command(label="Comic Sans MS", command=lambda: fontSettings("Comic Sans MS"))
+    FontSettings.add_command(label="Calibri", command=lambda: fontSettings("Calibri"))
+    FontSettings.add_command(label="Times New Roman", command=lambda: fontSettings("Times New Roman"))
+    FontSettings.add_command(label="Lucida Calligraphy", command=lambda: fontSettings("Lucida Calligraphy"))
+    FontSettings.add_command(label="Lucida Handwriting", command=lambda: fontSettings("Lucida Handwriting"))
 
     viewMenu = Menu(menu, tearoff=False)
     menu.add_cascade(label="View", menu=viewMenu)
@@ -686,6 +905,9 @@ def main():
     viewMenu.add_command(label="Time and Date", command=lambda: timeDate(False))
     viewMenu.add_separator()
     viewMenu.add_command(label="Clock Widget", command=lambda: clock(False))
+    viewMenu.add_separator()
+    viewMenu.add_command(label="Show Month Calendar", command=show_month_calendar)
+    viewMenu.add_command(label="Show Year Calendar", command=show_year_calendar)
     
     searchMenu = Menu(menu, tearoff=False)
     menu.add_cascade(label="Search", menu=searchMenu)
@@ -701,10 +923,16 @@ def main():
     toolsMenu.add_command(label="Qr-Code Generator", command=lambda: qr(False))
     toolsMenu.add_command(label="Insert Month Calendar", command=lambda: month_calendar(False))
     toolsMenu.add_command(label="Insert Year Calendar", command=lambda: year_calendar(False))
+    # toolsMenu.add_command(label="Insert Profile", command=writer_profile)
+    toolsMenu.add_separator()
+    toolsMenu.add_command(label="Run File", command=lambda: run(False))
     toolsMenu.add_separator()
     toolsMenu.add_command(label="Generate sha256 Hash", command=hash_sha256)
     toolsMenu.add_command(label="Generate md5 Hash", command=hash_md5)
     toolsMenu.add_command(label="Generate sha1 Hash", command=hash_sha1)
+    # toolsMenu.add_separator()
+    # toolsMenu.add_command(label="Edit with Vim", command=vim_)
+    # toolsMenu.add_command(label="Edit with Nano", command=nano_)
 
     colorMenu = Menu(menu, tearoff=False)
     menu.add_cascade(label="Color", menu=colorMenu)
@@ -734,6 +962,38 @@ def main():
     scroll_text.config(command=text.yview)
     horizontal_scroll.config(command=text.xview)
 
+    rightClickmenu = Menu(gui, tearoff=False)
+    rightClickmenu.add_command(label="Open File", command= lambda: openFile(False))
+    rightClickmenu.add_command(label="New File", command= lambda: newFile(False))
+    rightClickmenu.add_command(label="Save File", command= lambda: saveFile(False))
+    rightClickmenu.add_separator()
+    rightClickmenu.add_command(label="Copy", command= lambda: copyText(False))
+    rightClickmenu.add_command(label="Cut", command= lambda: cutText(False))
+    rightClickmenu.add_command(label="Paste", command= lambda: pasteText(False))
+    rightClickmenu.add_separator()
+    rightClickmenu.add_command(label="Bold", command=lambda: boldText(False))
+    rightClickmenu.add_command(label="Italic", command=lambda: italicText(False))
+    rightClickmenu.add_command(label="Underline", command=lambda: underlineText(False))
+    rightClickmenu.add_separator()
+    rightClickmenu.add_command(label="Select All", command= lambda: selectAll(False))
+    rightClickmenu.add_command(label="Clear All", command= lambda: clearAll(False))
+    rightClickmenu.add_command(label="Delete Selected", command= lambda: del_text(False))
+    rightClickmenu.add_separator()
+    rightClickmenu.add_command(label="Insert Time", command= lambda: timeDate(False))
+    rightClickmenu.add_command(label="Insert Month Calendar", command= lambda: month_calendar(False))
+    rightClickmenu.add_separator()
+    rightClickmenu.add_command(label="Toggle FullScreen", command= lambda: fullScreen(False))
+    rightClickmenu.add_separator()
+    rightClickmenu.add_checkbutton(label="Word Wrap")
+    rightClickmenu.add_separator()
+    rightClickmenu.add_command(label="Light Theme", command= lambda: lightTheme(False))
+    rightClickmenu.add_command(label="Dark Theme", command= lambda: darkTheme(False))
+    rightClickmenu.add_separator()
+    # rightClickmenu.add_command(label="Settings", command= lambda: settings(False))
+    # rightClickmenu.add_separator()
+    rightClickmenu.add_command(label="Quit", command= lambda: quit1(False))
+    rightClickmenu.add_command(label="Save & Exit", command= lambda: save_exit(False))
+
     gui.bind('<Control-Key-x>', cutText)
     gui.bind('<Control-Key-c>', copyText)
     gui.bind('<Control-Key-v>', pasteText)
@@ -747,6 +1007,7 @@ def main():
     gui.bind('<Control-a>', selectAll)
     gui.bind('<Control-l>', clearAll)
     gui.bind('<Control-L>', clearAll)
+    gui.bind('<Delete>', del_text)
     gui.bind('<Control-b>', boldText)
     gui.bind('<Control-i>', italicText)
     gui.bind('<Control-u>', underlineText)
@@ -762,11 +1023,117 @@ def main():
     gui.bind('<Control-t>', qr)
     gui.bind('<Control-m>', month_calendar)
     gui.bind('<Control-y>', year_calendar)
-    gui.bind('<Control-r>', clock)
+    gui.bind('<Control-Key-*>', clock)
     gui.bind('<Control-w>', timeDate)
-
+    gui.bind('<Button-3>', right_click_menu)
+    gui.bind('<Control-Key-plus>', zoomIn)
+    gui.bind('<Control-Key-minus>', zoomOut)
+    gui.bind('<Control-r>', run)
 
     gui.mainloop()
 
-if __name__ == '__main__':
-    main()
+def cli(e):
+    from rich.console import Console
+    from rich.syntax import Syntax
+    from rich.markdown import Markdown
+    file = open(e, 'r')
+    content = file.read()
+    if e.endswith(".py"):
+        lang = "python"
+        my_code = content
+        syntax = Syntax(my_code, lang, theme="monokai", line_numbers=True)
+        console = Console()
+        console.print(syntax)
+        file.close
+    if e.endswith(".html"):
+        lang = "html"
+        my_code = content
+        syntax = Syntax(my_code, lang, theme="monokai", line_numbers=True)
+        console = Console()
+        console.print(syntax)
+        file.close
+    if e.endswith(".md"):
+        console = Console()
+        with open(e) as readme:
+            markdown = Markdown(readme.read())
+        console.print(markdown)
+    if e.endswith(".rb"):
+        lang = "ruby"
+        my_code = content
+        syntax = Syntax(my_code, lang, theme="monokai", line_numbers=True)
+        console = Console()
+        console.print(syntax)
+        file.close
+    if e.endswith(".java"):
+        lang = "java"
+        my_code = content
+        syntax = Syntax(my_code, lang, theme="monokai", line_numbers=True)
+        console = Console()
+        console.print(syntax)
+        file.close
+    if e.endswith(".js"):
+        lang = "Javascript"
+        my_code = content
+        syntax = Syntax(my_code, lang, theme="monokai", line_numbers=True)
+        console = Console()
+        console.print(syntax)
+        file.close
+    if e.endswith(".sh"):
+        lang = "shell"
+        my_code = content
+        syntax = Syntax(my_code, lang, theme="monokai", line_numbers=True)
+        console = Console()
+        console.print(syntax)
+        file.close
+    if e.endswith(".bat"):
+        lang = "batch"
+        my_code = content
+        syntax = Syntax(my_code, lang, theme="monokai", line_numbers=True)
+        console = Console()
+        console.print(syntax)
+        file.close
+    if e.endswith(".txt"):
+        lang = "text"
+        my_code = content
+        syntax = Syntax(my_code, lang, theme="monokai", line_numbers=True)
+        console = Console()
+        console.print(syntax)
+        file.close
+    else:
+        lang = "text"
+        my_code = content
+        syntax = Syntax(my_code, lang, theme="monokai", line_numbers=True)
+        console = Console()
+        console.print(syntax)
+        file.close
+
+try:
+    if sys.argv[1] == "-r":
+        try:
+            os.system('clear')
+        except:
+            os.system('cls')
+        print("NoobNote CLI")
+        x = sys.argv[2]
+        cli(x)
+    elif sys.argv[1] == "-w" :
+        try:
+            name = sys.argv[2]
+            print("NoobNote CLI")
+            input_content = str(input("Enter Input:\n"))
+            file = open(name, 'w')
+            file.write(input_content)
+            file.close  
+        except:
+            print("NoobNote CLI")
+            input_content = str(input("Enter Input:\n"))
+            name = str(input("Enter name:\n"))
+            file = open(name, 'w')
+            file.write(input_content)
+            file.close 
+
+except:
+    if __name__ == '__main__':
+        main()
+
+
